@@ -1,19 +1,13 @@
-from pathlib import Path, PurePath
-from tempfile import TemporaryDirectory
+from pathlib import Path
 import base64
 import io
 import re
-import urllib.parse
 
 import mistune
-import requests
 from nbconvert.preprocessors import ExecutePreprocessor, Preprocessor
-from traitlets import Instance, Unicode
-
-from ._screenshot import make_repr_png
 
 
-def get_image_files(md_source):
+def get_image_files(md_source, only_http=False):
     '''
     Return all image files from a markdown cell
 
@@ -22,20 +16,26 @@ def get_image_files(md_source):
     md_source : str
         Markdown text from cell['source']
     '''
-    pat_inline = r'\!\[.*?\]\((.*?\.(?:gif|png|jpg|jpeg|tiff))'
-    pat_ref = r'\[.*?\]:\s*(.*?\.(?:gif|png|jpg|jpeg|tiff))'
+    pat_inline = r'\!\[.*?\]\((.*?\.(?:gif|png|jpg|jpeg|tiff|svg))'
+    pat_ref = r'\[.*?\]:\s*(.*?\.(?:gif|png|jpg|jpeg|tiff|svg))'
     inline_files = re.findall(pat_inline, md_source)
     ref_files = re.findall(pat_ref, md_source)
     possible_image_files = inline_files + ref_files
     image_files = []
     for file in possible_image_files:
         p = file.strip()
-        if p not in image_files and not p.startswith('attachment') and not p.startswith('http'):
-            image_files.append(p)
+        is_http = p.startswith('http://') or p.startswith('https://')
+        is_attachment = p.startswith('attachment')
+        if p not in image_files:
+            if is_http:
+                if only_http:
+                    image_files.append(p)
+            elif not (is_attachment or only_http):
+                image_files.append(p)
     return image_files
 
 
-def replace_md_tables(md_source, converter, image_data_dict, cell_index):
+def replace_md_tables(image_data_dict, md_source, converter, cell_index):
     i = 0
     table = re.compile(r'^ *\|(.+)\n *\|( *[-:]+[-| :]*)\n((?: *\|.*(?:\n|$))*)\n*', re.M)
     nptable = re.compile(r'^ *(\S.*\|.*)\n *([-:]+ *\|[-| :]*)\n((?:.*\|.*(?:\n|$))*)\n*', re.M)
@@ -44,61 +44,61 @@ def replace_md_tables(md_source, converter, image_data_dict, cell_index):
         nonlocal i
         md = match.group()
         html = mistune.markdown(md, escape=False)
+        html = '<div>' + html + '</div>'
         image_data = base64.b64decode(converter(html))
         new_image_name = f'markdown_{cell_index}_table_{i}.png'
         image_data_dict[new_image_name] = image_data
         i += 1
-        return f'![]({new_image_name})'
+        return f'![]({new_image_name})\n'
     
     md_source = nptable.sub(md_table_to_image, md_source)
     md_source = table.sub(md_table_to_image, md_source)
     return md_source
 
 
-def get_image_tags(md_source):
+def get_image_tags(md_source, only_http=False):
     pat_img_tag = r'''(<img.*?[sS][rR][Cc]\s*=\s*['"](.*?)['"].*?/>)'''
     img_tag_files = re.findall(pat_img_tag, md_source)
-    return img_tag_files
+
+    kept_files = []
+    for entire_tag, src in img_tag_files:
+        is_http = src.startswith('http://') or src.startswith('https://')
+        if is_http:
+            if only_http:
+                kept_files.append((entire_tag, src))
+        elif not only_http:
+            kept_files.append((entire_tag, src))
+
+    return kept_files
 
 
 class MarkdownPreprocessor(Preprocessor):
 
-
-    image_data_dict = Instance(klass=dict)
-
     def preprocess_cell(self, cell, resources, cell_index):
         nb_home = Path(resources['metadata']['path'])
+        image_data_dict = resources['image_data_dict']
         if cell['cell_type'] == 'markdown':
-
             # find normal markdown images 
-            # can normal images be http?
             all_image_files = get_image_files(cell['source'])
             for i, image_file in enumerate(all_image_files):
-                image_data = open(nb_home / image_file, 'rb').read()
                 ext = Path(image_file).suffix
                 if ext.startswith('.jpg'):
                     ext = '.jpeg'
-                    
                 new_image_name = f'markdown_{cell_index}_normal_image_{i}{ext}'
+                image_data = open(nb_home / image_file, 'rb').read()
                 cell['source'] = cell['source'].replace(image_file, new_image_name)
-                self.image_data_dict[new_image_name] = image_data
+                image_data_dict[new_image_name] = image_data
 
             # find HTML <img> tags
             all_image_tag_files = get_image_tags(cell['source'])
             for i, (entire_tag, src) in enumerate(all_image_tag_files):
-                if src.startswith('http'):
-                    replace_str = f'![]({src})'
-                else:
-                    image_data = open(nb_home / src, 'rb').read()
-                    ext = Path(src).suffix
-                    if ext.startswith('.jpg'):
-                        ext = '.jpeg'
-                    new_image_name = f'markdown_{cell_index}_html_image_tag_{i}{ext}'
-                    replace_str = f'![]({new_image_name})'
-                    # only save non-http tags. http tags will direct link from markdown
-                    self.image_data_dict[new_image_name] = image_data
-                    
-                cell['source'] = cell['source'].replace(entire_tag, replace_str)
+                ext = Path(src).suffix
+                if ext.startswith('.jpg'):
+                    ext = '.jpeg'
+                new_image_name = f'markdown_{cell_index}_local_image_tag_{i}{ext}'
+                image_data = open(nb_home / src, 'rb').read()
+                image_data_dict[new_image_name] = image_data
+                cell['source'] = cell['source'].replace(entire_tag, f'![]({new_image_name})')
 
             # find images attached to markdown through dragging and dropping
             attachments = cell.get('attachments', {})
@@ -112,20 +112,21 @@ class MarkdownPreprocessor(Preprocessor):
                         ext = 'jpeg'
                     new_image_name = f'markdown_{cell_index}_attachment_{i}_{j}.{ext}'
                     image_data = base64.b64decode(base64_data)
-                    self.image_data_dict[new_image_name] = image_data
+                    image_data_dict[new_image_name] = image_data
                     cell['source'] = cell['source'].replace(f'attachment:{image_name}', new_image_name)
 
             # find markdown tables
-            cell['source'] = replace_md_tables(cell['source'], resources['converter'], 
-                                               self.image_data_dict, cell_index)
+            cell['source'] = replace_md_tables(image_data_dict, cell['source'], 
+                                               resources['converter'], cell_index)
             
         return cell, resources
 
-
+# converts DataFrames to images when not executing notebook first
+# also converts gifs to png for outputs since jinja template is missing this
+# could write a custom template to handle this
 class NoExecuteDataFramePreprocessor(Preprocessor):
         
     def preprocess_cell(self, cell, resources, index):
-        nb_home = Path(resources['metadata']['path'])
         converter = resources['converter']
         if cell['cell_type'] == 'code':
             outputs = cell.get('outputs', [])
