@@ -1,8 +1,6 @@
-from pathlib import Path
 import json
-import re
 import urllib.parse
-from tempfile import TemporaryDirectory
+from pathlib import Path
 
 import requests
 import nbformat
@@ -39,13 +37,11 @@ class Publish:
         self.save_markdown = save_markdown
         self.table_conversion = table_conversion
         self.nb_home = self.filename.parent
-        self.image_dir = TemporaryDirectory()
         self.resources = self.get_resources()
         self.nb = self.get_notebook()
         self.headers = self.get_headers()
         self.validate_args()
 
-
     def validate_args(self):
         if self.publish_status != 'draft':
             raise ValueError('Only "draft" is allowed as a publish status for now')
@@ -63,9 +59,17 @@ class Publish:
             raise ValueError('`table_version` must be either "chrome" or "matplotlib"')
         
     def get_resources(self):
+        if self.table_conversion == 'chrome':
+            from ._screenshot import Screenshot
+            converter = Screenshot(center_df=True, fontsize=14, chrome_path=self.chrome_path).run
+        else:
+            from ._matplotlib_table import TableMaker
+            converter = TableMaker(fontsize=22).run
+
         resources = {'metadata': {'path': str(self.nb_home), 
                                   'name': self.title},
-                     'output_files_dir': self.image_dir.name}
+                     'converter': converter,
+                     'image_data_dict': {}}
         return resources
 
     def get_notebook(self):
@@ -112,24 +116,20 @@ class Publish:
                          f'Here is the publication data returned from Medium\n\n{data}')
 
     def create_markdown(self):
-        if self.table_conversion == 'chrome':
-            converter = Screenshot(max_rows=30, max_cols=10, ss_width=1400, 
-                                   ss_height=900, resize=1, chrome_path=None).run
-        else:
-            from ._matplotlib_table import converter
-        self.resources['converter'] = converter
-
-        mp = MarkdownPreprocessor(image_data_dict={})
-        self.nb, self.resources = mp.preprocess(self.nb, self.resources)
+        mp = MarkdownPreprocessor()
+        mp.preprocess(self.nb, self.resources)
 
         no_ex_pp = NoExecuteDataFramePreprocessor()
-        self.nb, self.resources = no_ex_pp.preprocess(self.nb, self.resources)
+        no_ex_pp.preprocess(self.nb, self.resources)
 
         # MarkdownExporter converts images to base64 bytes automatically
+        # MarkdownExporter deep copies resources and fails when matplotlib
+        # must remove converter key to not error
+        self.resources.pop('converter') 
         me = MarkdownExporter()
         md, self.resources = me.from_notebook_node(self.nb, self.resources)
 
-        image_data_dict = {**mp.image_data_dict, **self.resources['outputs']}
+        image_data_dict = {**self.resources['image_data_dict'], **self.resources['outputs']}
         return md, image_data_dict
 
     def load_images_to_medium(self):
@@ -150,7 +150,6 @@ class Publish:
                 self.md = self.md.replace(file, new_url)
                 all_json.append(req_json)
         
-        # with open(self.nb_home / self.img_data_json, 'w') as f:
         print('\n\nImage Storage Information from Medium')
         print('-------------------------------------\n')
         print(json.dumps(all_json, indent=4))
@@ -239,7 +238,7 @@ def publish(filename, integration_token=None, pub_name=None, title=None,
         Location of Jupyter Notebook to publish to Medium.
 
     integration_token : str, default None
-        When `None`, the integration token must be stored in a file
+        When None, the integration token must be stored in a file
         located in the users home directory at 
         '.jupyter_to_medium/integration_token'. You'll need to create 
         this directory and file first and paste your token there.
@@ -249,18 +248,18 @@ def publish(filename, integration_token=None, pub_name=None, title=None,
         Learn how to get an integration token from Medium.
         https://github.com/Medium/medium-api-docs
     
-    pub_name : str, default `None`
+    pub_name : str, default None
         Name of Medium publication. Not necessary if publishing as a user.
         
-    title : str, default `None`
+    title : str, default None
         This title is used for SEO and when rendering the post as a listing, 
         but will not appear in the actual post. Use the first cell of the 
         notebook with an H1 markdown header for the title. 
         i.e. # My Actual Blog Post Title 
     
-        Leave as `None` to use the filename as this title
+        Leave as None to use the filename as this title
     
-    tags : list of strings, default `None`
+    tags : list of strings, default None
         List of tags to classify the post. Only the first five will be used. 
         Tags longer than 25 characters will be ignored.
     
@@ -276,11 +275,11 @@ def publish(filename, integration_token=None, pub_name=None, title=None,
         'cc-40-by-sa', 'cc-40-by-nd', 'cc-40-by-nc', 'cc-40-by-nc-nd', 'cc-40-by-nc-sa', 
         'cc-40-zero', 'public-domain'. The default is 'all-rights-reserved'.
     
-    canonical_url : str, default `None`
+    canonical_url : str, default None
         A URL of the original home of this content, if it was originally 
         published elsewhere.
 
-    chrome_path : str, default `None`
+    chrome_path : str, default None
         Path to your machine's chrome executable. By default, it is 
         automatically found. Use this when chrome is not automatically found.
 
@@ -290,15 +289,15 @@ def publish(filename, integration_token=None, pub_name=None, title=None,
         in a folder with _files appended to it.
 
     table_conversion : 'chrome' or 'matplotlib', default 'chrome'
-        Medium does not render tables correctly such as pandas DataFrame.
+        Medium does not render tables correctly such as pandas DataFrames.
         As a workaround, images of the tables will be produced in their place.
         When 'chrome', a screenshot using the Chrome web browser will be used.
         When 'matplotlib', the matplotlib table function will be used to
-        produce the table
+        produce the table.
         
     '''
     p = Publish(filename, integration_token, pub_name, title, tags, 
                 publish_status, notify_followers, license, canonical_url,
                 chrome_path, save_markdown, table_conversion)
     p.main()
-    return p.result
\ No newline at end of file
+    return p.result
